@@ -1,6 +1,6 @@
 matched <- function(matchobject) {
 ans <- logical(length(matchobject))
-if (!any(class(matchobject)=='optmatch')) {
+if (!inherits(matchobject,'optmatch')) {
   warning('argument of matched() not of class \'optmatch\'', call.=FALSE)
         }
 ans[grep("[.][123456789][0123456789]*$", as.character(matchobject))] <- TRUE
