@@ -1,6 +1,6 @@
 matched.distances <- function(matchobj, distance, preserve.unit.names=FALSE)
   {
-stopifnot(class(matchobj)[1]=="optmatch")
+stopifnot(inherits(matchobj,"optmatch"))
 
 finddist.mat <- function(dmat, omobj)
   {
@@ -11,7 +11,7 @@ tapply(names(omobj),omobj, FUN=function(x,DMAT){
 }, dmat)
   }
 
-if (class(distance)[1]!="optmatch.dlist")
+if (!inherits(distance,"optmatch.dlist"))
   {
 return(finddist.mat(distance, matchobj))
   } else {
@@ -26,6 +26,3 @@ return(res[levels(matchobj)])
   }
 
   }
-
-### a (for now) private helper to compute if any matched.distances are considered
-### outliers --Removed in revision 113 (-BH)
